@@ -16,7 +16,7 @@
 # This script will start the datastore server listening on an available socket
 serverpath=.;
 
-CLASSPATH=.:dstore_extra_server.jar:dstore_core.jar:dstore_miners.jar:clientserver.jar:cdtminer.jar:cdtmodel.jar:cdtparser.jar:org.eclipse.core.runtime_3.6.0.v20100505.jar:org.eclipse.equinox.common_3.6.0.v20100503.jar:org.eclipse.core.filesystem_1.3.0.v20100526-0737.jar:com.ibm.icu.base_4.2.1.v20100412.jar:stubs.jar:lrparser.jar:upcparser.jar:xlcparser.jar:spawner.jar:net.sourceforge.lpg.lpgjavaruntime_1.1.0.v200803061910.jar:$CLASSPATH;
+CLASSPATH=.:dstore_extra_server.jar:dstore_core.jar:dstore_miners.jar:clientserver.jar:cdtminer.jar:cdtmodel.jar:cdtparser.jar:org.eclipse.core.runtime_3.6.0.v20100505.jar:org.eclipse.equinox.common_3.6.0.v20100503.jar:org.eclipse.core.filesystem_1.3.1.R36x_v20100727-0745.jar:com.ibm.icu.base_4.2.1.v20100412.jar:stubs.jar:lrparser.jar:upcparser.jar:xlcparser.jar:spawner.jar:net.sourceforge.lpg.lpgjavaruntime_1.1.0.v200803061910.jar:$CLASSPATH;
 export serverpath CLASSPATH
 
 
